<?php

/*

LICENSE AND COPYRIGHT

Copyright (C) 2012 Collier Technologies LLC. DBA colliertech.org
Copyright (C) 2012 colliertech.org

This program is free software; you can redistribute it and/or modify it
under the terms of either: the GNU General Public License as published
by the Free Software Foundation; or the Artistic License.

See http://dev.perl.org/licenses/ for more information.

*/

?>
