<?php
/**
 Plugin Name: colliertech.org' Wall Flower
 Plugin URI: http://wp.colliertech.org/downloads/wallflower.zip
 Description: colliertech.org' Wall Flower mostly holds the wall up at dances..
 Author: C.J. Adams-Collier
 Version: 0.0.2
 Author URI: http://wp.colliertech.org/cj/
 */

include_once('license.php');

echo "boy.  is this thing ever on.";

?>

