package WordPress::Plugin::WallFlower;

use warnings;
use strict;

=head1 NAME

WordPress::Plugin::WallFlower - Holding Dance Floor Walls up since 20120810174359 Pacific Time.

=head1 VERSION

Version 0.0.2

=cut

our $VERSION = '0.0.2';


=head1 SYNOPSIS

    use WordPress::Plugin::WallFlower;

    # yeah, that's about it.  Nope.  Nothing else at this time.

=head1 EXPORT

=head1 SUBROUTINES/METHODS

=head2 your_mother

    Randomly insults your mother

=cut

sub your_mother {
	return "you know, MC Hawking wrote a really great song about your mother.";
}

=head1 AUTHOR

C.J. Adams-Collier, C<< <cjac at colliertech.org> >>

=head1 BUGS

Please report any bugs or feature requests to C<bug-wordpress-plugin-wallflower at rt.cpan.org>, or through
the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=WordPress-Plugin-WallFlower>.  I will be notified, and then you'll
automatically be notified of progress on your bug as I make changes.




=head1 SUPPORT

You can find documentation for this module with the perldoc command.

    perldoc WordPress::Plugin::WallFlower


You can also look for information at:

=over 4

=item * RT: CPAN's request tracker

L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=WordPress-Plugin-WallFlower>

=item * AnnoCPAN: Annotated CPAN documentation

L<http://annocpan.org/dist/WordPress-Plugin-WallFlower>

=item * CPAN Ratings

L<http://cpanratings.perl.org/d/WordPress-Plugin-WallFlower>

=item * Search CPAN

L<http://search.cpan.org/dist/WordPress-Plugin-WallFlower/>

=back


=head1 ACKNOWLEDGEMENTS


=head1 LICENSE AND COPYRIGHT

Copyright 2012 Collier Technologies LLC DBA colliertech.org
Copyright 2012 colliertech.org

This program is free software; you can redistribute it and/or modify it
under the terms of either: the GNU General Public License as published
by the Free Software Foundation; or the Artistic License.

See http://dev.perl.org/licenses/ for more information.


=cut

1; # End of WordPress::Plugin::WallFlower
